#!/usr/bin/env python3

class command():
    def __init__(self):
        pass
    
    def initialize(self, environment):
        self.env = environment
    
    def shutdown(self):
        pass
    
    def getDescription(self):
        return "Discard temporary changes and revert to saved settings"
    
    def run(self):
        self.env['runtime']['outputManager'].presentText("Reverting to saved configuration...", interrupt=True)
        
        try:
            # Reload settings from file, discarding runtime changes
            settingsManager = self.env['runtime']['settingsManager']
            settingsManager.loadSettings()
            
            # Reinitialize speech system with restored settings
            if 'speechDriver' in self.env['runtime']:
                try:
                    speechDriver = self.env['runtime']['speechDriver']
                    speechDriver.shutdown()
                    speechDriver.initialize(self.env)
                except:
                    pass
            
            # Reinitialize sound system with restored settings  
            if 'soundDriver' in self.env['runtime']:
                try:
                    soundDriver = self.env['runtime']['soundDriver']
                    soundDriver.shutdown()
                    soundDriver.initialize(self.env)
                except:
                    pass
            
            self.env['runtime']['outputManager'].presentText("Successfully reverted to saved settings", interrupt=False, flush=False)
            self.env['runtime']['outputManager'].presentText("All temporary changes have been discarded", interrupt=False, flush=False)
            
        except Exception as e:
            self.env['runtime']['outputManager'].presentText(f"Error reverting settings: {str(e)}", interrupt=False, flush=False)
            self.env['runtime']['outputManager'].presentText("You may need to restart Fenrir", interrupt=False, flush=False)
    
    def setCallback(self, callback):
        pass